#import "DataManager.h"
#import <SystemConfiguration/SCNetworkReachability.h>
#include <netinet/in.h>


@interface DataManager (Private)

- (void) createLevels;

@end

@implementation DataManager

@synthesize defaults, mInsertIdx, mTime, aryHighScores,aryPlayerName;

- (void) dealloc
{
	[aryPlayerName release];
	[aryHighScores release];
	[defaults release];
	[super dealloc];
}

-(id) init
{
	self = [super init];
	
	if (self)
	{
		defaults = [NSUserDefaults standardUserDefaults];
				
		[self loadFiles];
	}
	
	return self;
}

-(void) loadFiles
{
	NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
	NSString *documentsDirectory = [paths objectAtIndex:0];
	NSString* scoreFilePath = [documentsDirectory stringByAppendingPathComponent:@"highscores.plist"];
	NSString* nameFilePath = [documentsDirectory stringByAppendingPathComponent:@"playername.plist"];
	
	if ([[NSFileManager defaultManager] fileExistsAtPath:scoreFilePath]
		&&[[NSFileManager defaultManager] fileExistsAtPath:nameFilePath])
	{
		self.aryHighScores = [[NSMutableArray alloc] initWithContentsOfFile:scoreFilePath];
		self.aryPlayerName = [[NSMutableArray alloc] initWithContentsOfFile:nameFilePath];				
	}
	else
	{
		self.aryHighScores = [NSMutableArray arrayWithObjects:@"0",@"0",@"0",@"0",@"0",@"0",@"0",@"0",@"0",@"0",nil];//0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,nil];
		self.aryPlayerName = [NSMutableArray arrayWithObjects:@"-----",@"-----",@"-----",@"-----",@"-----",@"-----",@"-----",@"-----",@"-----",@"-----",nil];
		[self.aryHighScores writeToFile:scoreFilePath atomically:YES];
		[self.aryPlayerName writeToFile:nameFilePath atomically:YES];
	}
}

-(void) saveFiles:(NSString*)timeStr name:(NSString*)nameStr
{
	[self.aryHighScores insertObject:timeStr atIndex:self.mInsertIdx];
	[self.aryHighScores removeLastObject];
	[self.aryPlayerName insertObject:nameStr atIndex:self.mInsertIdx];
	[self.aryPlayerName removeLastObject];
	
	NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
	NSString *documentsDirectory = [paths objectAtIndex:0];
	NSString* scoreFilePath = [documentsDirectory stringByAppendingPathComponent:@"highscores.plist"];
	NSString* nameFilePath = [documentsDirectory stringByAppendingPathComponent:@"playername.plist"];
	
	[self.aryHighScores writeToFile:scoreFilePath atomically:YES];
	[self.aryPlayerName writeToFile:nameFilePath atomically:YES];
	//double t1 = [[self.aryHighScores objectAtIndex:0] doubleValue];
	//NSLog([self.aryHighScores objectAtIndex:0]);
}


- (BOOL) connectedToNetwork
{/*
    // Create zero addy
    struct sockaddr_in zeroAddress;
    bzero(&zeroAddress, sizeof(zeroAddress));
    zeroAddress.sin_len = sizeof(zeroAddress);
    zeroAddress.sin_family = AF_INET;
	
    // Recover reachability flags
    SCNetworkReachabilityRef defaultRouteReachability = SCNetworkReachabilityCreateWithAddress(NULL, (struct sockaddr *)&zeroAddress);
    SCNetworkReachabilityFlags flags;
	
    BOOL didRetrieveFlags = SCNetworkReachabilityGetFlags(defaultRouteReachability, &flags);
    CFRelease(defaultRouteReachability);
	
    if (!didRetrieveFlags)
    {
        NSLog(@"Error. Could not recover network reachability flags");
        return NO;
    }
	
    BOOL isReachable = flags & kSCNetworkFlagsReachable;
    BOOL needsConnection = flags & kSCNetworkFlagsConnectionRequired;
	BOOL nonWiFi = flags & kSCNetworkReachabilityFlagsTransientConnection;
	
	NSURL *testURL = [NSURL URLWithString:@"http://www.apple.com/"];
	NSURLRequest *testRequest = [NSURLRequest requestWithURL:testURL  cachePolicy:NSURLRequestReloadIgnoringLocalCacheData timeoutInterval:20.0];
	NSURLConnection *testConnection = [[NSURLConnection alloc] initWithRequest:testRequest delegate:self];
	
    return ((isReachable && !needsConnection) || nonWiFi) ? (testConnection ? YES : NO) : NO;
 */
	return NO;
}

/////////////////////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////// Singleton ///////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////////////////////

static DataManager *sharedDataManager = nil;

+ (DataManager *) sharedManager
{
    @synchronized(self)
	{
        if (sharedDataManager == nil)
		{
            [[self alloc] init];
        }
    }
	
    return sharedDataManager;
}

+ (id)allocWithZone:(NSZone *)zone
{
    @synchronized(self)
	{
        if(sharedDataManager == nil)
		{
            sharedDataManager = [super allocWithZone:zone];
            return sharedDataManager;
        }
    }
	
    return nil;
}

- (id)copyWithZone:(NSZone *)zone
{	
    return self;
}

- (id) retain
{
    return self;
}

- (unsigned) retainCount
{
    return UINT_MAX;
}

- (void)release
{
	
}

- (id) autorelease
{
    return self;
}

@end
