

#import "MenuLayer.h"
#import "DataManager.h"

#define MAX_CLOUDS 2

@interface MenuLayer()
//private function
- (void)updateBackground;

@end

@implementation MenuLayer

@synthesize Delegate = mDelegate,enable;

- (void) dealloc
{
	//mbg cloud array release
	[mMip release];
	[mDelegate release];
	//[menu release];
	[super dealloc];
}

-(id) init
{
	self = [super init];
	
	if (self)
	{
		enable = YES;
		
		mMip = [[MIP alloc] init];
		[[Director sharedDirector].openGLView addSubview:[mMip view]];
		[mMip mpSetShuffleMode:MPMusicShuffleModeOff setRepeatMode:MPMusicRepeatModeAll];
		//[mMip mpSetVolume:[mMip mpGetVolume]*0.4];
		
		[MenuItemFont setFontSize:25];
        [MenuItemFont setFontName:@"Marker Felt"];
		
        MenuItem *start = [MenuItemImage itemFromNormalImage:@"menu_story mode_1.png" selectedImage:@"menu_story mode_2.png"
												target:self
											  selector:@selector(restartGame:)];//diable image
				
		MenuItem *scores = [MenuItemImage itemFromNormalImage:@"menu_scores_1.png" selectedImage:@"menu_scores_2.png"
													target:self
												  selector:@selector(highScores:)];
		
		MenuItem *about = [MenuItemImage itemFromNormalImage:@"menu_credits_1.png" selectedImage:@"menu_credits_2.png"
													target:self
												  selector:@selector(about:)];
		
		Menu* menu = [Menu menuWithItems:start, [MenuLayer getSpacerItem], scores, [MenuLayer getSpacerItem], about, nil];
		
        [menu alignItemsVertically];
		start.position = ccp(start.position.x-60,start.position.y);
		scores.position = ccp(scores.position.x + 18, scores.position.y);
		about.position = ccp(scores.position.x -60, about.position.y);
		menu.position = ccp(212,175);
        [self addChild:menu z:2];
		
		Sprite*  menu_bg = [Sprite spriteWithFile:@"main_menu_bg.png"];
		menu_bg.position= ccp(WIN_WIDTH/2,WIN_HEIGHT/2);
		[self addChild:menu_bg z:0 ];
		Sprite* guitar = [Sprite spriteWithFile:@"guitar.png"];
		guitar.anchorPoint = ccp(0,0);
		guitar.position = ccp(0,0);
		[self addChild:guitar z:2];
		Sprite* logo = [Sprite spriteWithFile:@"logo.png"];
		logo.position = ccp(WIN_WIDTH/2+30,385.5);
		[self addChild:logo z:2];
		
		Sprite* bgCloud1 = [[Sprite alloc] initWithFile:@"cloud.png"];
		[[bgCloud1 texture] setAliasTexParameters];
		bgCloud1.position = ccp(WIN_WIDTH/2, WIN_HEIGHT/2);	
		[self addChild:bgCloud1 z:1];
		Sprite* bgCloud2 = [[Sprite alloc] initWithTexture:[bgCloud1 texture]];
		bgCloud2.position = ccp(bgCloud1.position.x, bgCloud1.position.y-WIN_HEIGHT);
		[self addChild:bgCloud2 z:1];	
		mBGCloudArray = [[NSArray alloc] initWithObjects:bgCloud1,bgCloud2,nil];
		[bgCloud1 release];
		[bgCloud2 release];
		
		
		[self schedule: @selector(update:) interval: 1.0 / 60.0];
	}
	
	return self;
}

- (void) updateBackground
{	
	Sprite* bgCloud;
	
	for (int i=0;i<MAX_CLOUDS;i++)
	{
		bgCloud = [mBGCloudArray objectAtIndex:i];
		
		bgCloud.position = ccp(bgCloud.position.x, bgCloud.position.y + 1.8);
		
		// if out of scope, flip to the bottom
		if ( bgCloud.position.y > (WIN_HEIGHT + WIN_HEIGHT/2))
		{
			bgCloud.position = ccp(bgCloud.position.x, bgCloud.position.y - WIN_HEIGHT*2);
		}
	}
	
	for (int i=0;i<MAX_CLOUDS;i++)
	{
		bgCloud = [mBGCloudArray objectAtIndex:i];

		// try to re-calibrate the position...
		int prevIndex = (i - 1 + MAX_CLOUDS) % MAX_CLOUDS;
		Sprite* prevCloud = [mBGCloudArray objectAtIndex:prevIndex];
		if ( prevCloud.position.y > bgCloud.position.y )
		{
			bgCloud.position = ccp(bgCloud.position.x, prevCloud.position.y - WIN_HEIGHT);
		}
	}
}

-(void) update:(ccTime)ticks
{
	[self updateBackground];
}

///////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////// Selector Methods /////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////

- (void) about:(id) sender
{
	if (enable)
	{
		[[SimpleAudioEngine sharedEngine] playEffect:kButtonSE];
		[[NSNotificationCenter defaultCenter] postNotificationName:@"about" object:@""];
		[mMip mpStopMusic];	
		[mMip showPicker:@"Select Music"];
	}
}

- (void) highScores:(id) sender
{
	if (enable)
	{
		[[SimpleAudioEngine sharedEngine] playEffect:kButtonSE];
		[[NSNotificationCenter defaultCenter] postNotificationName:@"showHighScores" object:@""];
		
		NSArray* rec = [NSArray arrayWithObjects:@"blzwow@gmail.com", @"blzwow@yahoo.com.cn",nil];
		[mMip utSendEMailTo:rec	cc:NULL subject:@"Hello World In Game EMail"
					   body:@"nothing to say" isHTML:NO];
	}
}

//- (void) moreGames:(id) sender
//{
	//[[NSNotificationCenter defaultCenter] postNotificationName:@"moreGames" object:@""];
//}

///////////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////// Delegate Methods /////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////

- (void) restartGame:(id) sender
{
	if (enable)
	{
		if ([mDelegate respondsToSelector:@selector(changeToInGame)]) 
		{
			[[SimpleAudioEngine sharedEngine] playEffect:kButtonSE];
			//[mDelegate restartGame];
			[mDelegate changeToInGame];
		}
	}
}

+ (MenuItemFont *) getSpacerItem
{
	[MenuItemFont setFontSize:2];
	return [MenuItemFont itemFromString:@" " target:self selector:nil];
}

@end
