//
//  TapjoyConnect.h
//  TapjoyConnectionClinet
//
//  Created by BayViewLabs on 16/02/09.
//  Copyright 2009 BayViewLabs. All rights reserved.
//
#define FULL_PAGE_AD_OPEN_NOTIFICATION @"TJC_FULL_PAGE_AD_OPEN_NOTIFICATION"
#define FULL_PAGE_AD_CLOSE_NOTIFICATION @"TJC_FULL_PAGE_AD_CLOSE_NOTIFICATION"

#define FULL_PAGE_AD_OPEN_NOTIFICATION @"TJC_FULL_PAGE_AD_OPEN_NOTIFICATION"
#define FULL_PAGE_AD_CLOSE_NOTIFICATION @"TJC_FULL_PAGE_AD_CLOSE_NOTIFICATION"
#define FULL_PAGE_AD_FAILURE_NOTIFICATION @"TJC_FULL_PAGE_AD_FAILURE_NOTIFICATION"

#import <UIKit/UIKit.h>
#import <CoreLocation/CoreLocation.h>

@class TJCAdView;
/*PROTOCOL CONSTANTS */	
@protocol TapjoyConnectDelegate;
@interface TapjoyConnect :  NSObject 
{
	
}
/**
 * Sets the delegate class to handle Tapjoy events, such as didReceiveConnection,
 * which many game applications will want to handle in order to connect to Tapjoy
 *
 * @param aDelegate	The delegate class instance, which must implement the
 *						TapjoyConnectDelegate protocol.
 * Note: should set delegate before calling any other object methods of TapjoyConnect object.
 */
+ (TapjoyConnect *)requestTapjoyConnectWithDelegate:(id<TapjoyConnectDelegate>)aDelegate;

/**
 * Invoke this to get connect your application with TapjoyConnect server.
 * This should be called while the app is loading. This fires off an asynchronous webservice call (Connect) to get all the information needed for the Connect Bar, 
 * and it logs this device into the webservice
 */
- (void)connect;
/**
 *
 * Invoke this method to enable Orientation for your Views.Takes RootViewController as its only argument
 */
+(void) enableOrientationWithRootViewController:(UIViewController*)rootViewController;

/**
 *
 * Invoke this method to update UIViewController for orientation of your Views.Takes top reference of your ViewController's Stack as its only argument.
 * Donot Invoke if you havent called enableOrientationWithRootViewController:(UIViewController*)rootViewController
 */
+(void) updateViewControllerForOrientation:(UIViewController *)topViewController;

/**
 * Invoke this method to fix Orientation of our library view to a particular orientation.
 * Takes your applicationView along with the angle of orientation
 * For Landsacpe(left and right),use angle as 90 and 270 respectively
 * For Portrait(portrait and portraitUpsideDown),use 0 and 180 respectively
 */

+(void) setFixedOrientation:(UIView*) appView WithAngel:(int) angel;


#pragma mark ADS
/**
 * This should be Invoke by the host application while the app is loading.  It caches the optimal ad order for this app instance
 */
- (void)getAdOrder;
/**
 * The host application can preload ads at appropriate times by passing EventID ,
 * EventID is might be a Level number and called while start of the new level.
 * @param anEventID	The event number, when you want to preload the add ,for 
 * example preloading of ads while start of the each level by passing level number as anEventID.
 */
- (void)preloadAds:(int)anEventID;
/**
 * This will show a preloaded ad if one exists or download a new ad and show it
 * EventID is might be a Level number and called while start of the new level.
 * @param anEventID	The event number, when you want to preload the add ,for 
 * example preloading of ads while start of the each level by passing level number as anEventID .
 * @param adBoxFrame	frame for returned adView. 
 */
- (TJCAdView *)showAdBox:(int)anEventID  rect:(CGRect)adBoxFrame;
/**
 *if app want to listen the protocol functions of showAdBox, call this function Note: Don't call setDelegate of TJCAdView in this case.
 * Always call this function if want to listen Protcol events 
 */
-(TJCAdView *)showAdBox:(int)anEventID  rect:(CGRect)adBoxFrame WithDelegate:(id) appDelegate;

-(void) showFullPageAd;
/**
 * Sets a forced rotation for ad display. Landscape-oriented apps will want
 * to make use of this.
 * Angles 90 and 270 = Landscape
 * Angles 0 and 180 Portrait
 * @param a_rotation	Angle of the rotation.
 */
-(void) fullPageAdOrientation:(float) a_rotation;

/**
 *Flurry Analytics functions for recording actions
 */
- (void)startSubBeaconWithName:(NSString *)beaconName timeSession:(BOOL)trackSession;
- (void)endSubBeaconWithName:(NSString *)beaconName;
- (void)setBeaconLocation:(CLLocation *)newLocation;

- (void)logEvent:(NSString *)eventName;
- (void)logEvent:(NSString *)eventName timed:(BOOL)timed;
- (void)logEvent:(NSString *)eventName withParameters:(NSDictionary *)parameters;
- (void)logEvent:(NSString *)eventName withParameters:(NSDictionary *)parameters timed:(BOOL)timed;
- (void)logError:(NSString *)errorID message:(NSString *)message exception:(NSException *)exception;
- (void)logError:(NSString *)errorID message:(NSString *)message error:(NSError *)error;
- (void)endTimedEvent:(NSString *)eventName;
- (void)countPageViews:(id)target;
- (void)countPageView;

/**
 *  Invoke this to get disconnect your application  from TapjoyConnect server.
 * This can be called when the app is terminating. 
 */
- (void)disconnect;

@end

@protocol TapjoyConnectDelegate<NSObject>

@required

// Use this to provide a application id for an application. 
- (NSString *)appID;

// Use this to provide a application password for an application 
- (NSString *)appPassword;

// Use this to provide a application version  
- (NSString *)appVersion;

@optional

// Sent when an application recieves a tapjoyconnection; this is a good opportunity to to store 
// connection and user info.
- (void)didReceiveConnection:(id)connectionResult;

// Sent when an application connect failed to connect to server.
- (void)didFailToReceiveConnection:(id)failedResult;

-(UIColor *)adsBackGroundColor;
-(CLLocation *)coreLocation;

@end


@interface TapjoyConnectInterface : NSObject<TapjoyConnectDelegate> {
	
}
@end

@interface TJCAdView : UIView 
{
}

-(void) setEventId:(int)eventId;
-(void) setDelegate:(id) delegate;
-(int) getEventId;
-(id) getDelegate;

-(NSString*) getAdLibraryName;
-(CGSize) getAdSize; // ad size of the retunred Ad
@end

@protocol TJCCustomAdsProtocol<NSObject>

@required
// When library throws this event user can start showing his custom Ad
-(void) showCustomAd:(TJCAdView*) adsObject;
// When library throws this event library wants it control back for continue its rotation
-(void) endCustomAd:(TJCAdView*) adsObject;

@end

@protocol TJCAdsSelectorProtocol<NSObject>

@optional
-(void) adIsShown:(TJCAdView*) adView;

@end


